@@ -1,5 +1,5 @@
-"gamStat" <-
-function(x)
+`gamStat` <-
+function(x, return.list=TRUE)
 {
     #includes final branching time.  See documentation for info(type '?gam.stat') on how
     # to omit this final branching time.
@@ -14,11 +14,15 @@ function(x)
     res$gamstat = s1/(T*sqrt(1/(12*(N-2))))
     res$pval = pnorm(res$gamstat, mean=0, sd=1)
     res$test = "one-tailed; Ho: rates have not decreased over time"
-    cat("------------------------------\n")
-    cat("Calculated gamma:", res$gamstat)
-    cat("\npvalue:", res$pval, "\n")
-    cat("test:", res$test, "\n")
-    cat("*assumes complete taxon sampling.\n")
-    return(res)
+    if (return.list){
+    	cat("------------------------------\n")
+    	cat("Calculated gamma:", res$gamstat)
+    	cat("\npvalue:", res$pval, "\n")
+    	cat("test:", res$test, "\n")
+    	cat("*assumes complete taxon sampling.\n");
+    	return(res);
+    }else{
+    	return(res$gamstat);	
+    }
 }
 
